@@ -29,12 +29,17 @@ class Player:
         self.storage.select_book(book)
         chapter, time = self.storage.get_time()
         self.audiobook = Audiobook.Audiobook(os.path.join(Paths.book_dir , book), chapter)
-        self.player.set_file(self.audiobook.get_current_chapter())
-        self.player.seek_time(time) 
+        
+        # self.player.set_file(self.audiobook.get_current_chapter())
+        # self.player.seek_time(time) 
+        
         if self.ui is not None:
             self.ui.set_book(book, self.audiobook.get_cover_img())
             self.ui.set_chapters(self.audiobook.chapters)
-        
+
+        chapter_title = self.audiobook.chapters[chapter]
+        self.set_chapter(chapter_title)
+
     def set_chapter(self, chapter):
         log.info("set chapter:" + chapter)
         self.audiobook.set_chapter(chapter)
@@ -42,7 +47,7 @@ class Player:
         self.storage.set_time(self.audiobook.current_chapter,0)
         
         if self.ui is not None:
-            self.ui.set_chapter(chapter)
+            self.ui.set_chapter(self.audiobook.current_chapter)
 
         
     def chapter_done(self,player):
